function writeActuatorSTO(fname,data,headings)

% Inputs
% fname    (str)         - file directory to save .sto file
% data     (matrix)      - n x nColumns matrix of data values where n = length(time)
% headings (cell of str) - 1 x nColumns cell array of column headers

%Determine data specific information
nCols = size(headings,2);
nRows = size(data,1);

% Open file for writing.
fid = fopen(fname, 'wt');

fprintf('\n      Printing Actuator STO file     \n');

if fid == -1
    error(['unable to open ', fname])
end

% Write header.
fprintf(fid,'%s\n','ActuatorForces');
fprintf(fid,'%s\n','version=1');
fprintf(fid,'nRows=%d\n',nRows);
fprintf(fid,'nColumns=%d\n',nCols);
fprintf(fid,'inDegrees=%s\n\n','no');
fprintf(fid,'%s\n','This file contains either the forces, speeds, or powers developed');
fprintf(fid,'%s\n\n','by the actuators of a model during a simulation.');
fprintf(fid,'%s\n\n','An actuator force is a generalized force, meaning that it can be either a force (N) or a torque (Nm).');
fprintf(fid,'%s\n','An actuator speed is the rate at which an actuator shortens. Depending on the actuator,');
fprintf(fid,'%s\n\n','a speed can be either a translational speed (m/s) or an angular speed (deg/s or rad/s).');
fprintf(fid,'%s\n','An actuator power (Watts) is the rate at which an actuator does work.  Positive power means');
fprintf(fid,'%s\n','that the actuator is delivering energy to the model; negative power means that the actuator');
fprintf(fid,'%s\n\n','is absorbing energy from the model.');
fprintf(fid,'%s\n','Units are S.I. units (second, meters, Newtons, ...)');
fprintf(fid,'%s\n\n','Angles are in radians.');
fprintf(fid,'%s\n','endheader');

%Write Column Headings
fprintf(fid,'%20s\t',headings{1,1});
for i = 2:nCols-1
	fprintf(fid,'%20s\t',headings{1,i});
end

fprintf(fid,'%20s\n',headings{1,end});


%Write data rows
for i = 1:nRows
    for j = 1:nCols
        actData = data(i,:);
        if isnan(actData(j))
            fprintf(fid,'%20.5f\t', 0);
        else
            fprintf(fid,'%20.5f\t', actData(j));
        end
    end
    if i ~= nRows
        fprintf(fid, '\n');
    end
end

fclose(fid);
return;