function writeNLPtoGRF(sto_fname,el_fname,data,headings,trName,bodies)

% Inputs
% sto_fname (str)         - file directory to save .sto file
% el_fname  (str)         - file directory to save external_loads.xml file
% data      (matrix)      - n x nColumns matrix of data values where n = length(time)
% headsings (cell of str) - 1 x nColumns cell array of column headers
% trName    (str)         - name of the trial
% bodies    (cell of str) - n x 3 cell array of OpenSim Frames where n = nExternalLoads
%						  - Column 1 = applied to frame
%						  - Column 2 = force expressed in frame
% 						  - Column 3 = point expressed in frame
 

import org.opensim.modeling.*

% Determine rows x columns        
nCols   = size(headings,1);
nRows   = size(data,1);

%% Write MOT file

% Open file for writing.
fid = fopen(sto_fname, 'wt');

fprintf('\n      Printing GRF file     \n');

if fid == -1
    error(['unable to open ', sto_fname])
end

% Write header.
fprintf(fid, 'name %s\n', trName);
fprintf(fid, 'datacolumns %d\n', nCols);
fprintf(fid, 'datarows %d\n', nRows);
fprintf(fid, 'range %d %d\n', data(1,1), data(end,1));
fprintf(fid, 'endheader\n\n');

%Write Column Headings
for i = 1:nCols
	fprintf(fid,'%20s\t',headings{i});
end

%Write data rows
for i = 1:nRows
    fprintf(fid, '\n');
    for j = 1:nCols
        if isnan(data(i,j))
            fprintf(fid,'%20.5f\t', 0);
        else
            fprintf(fid,'%20.5f\t', data(i,j));
        end
    end
end

fclose(fid);

fprintf('\n      Printing GRF file complete    \n');

%% CREATE EXTERNAL LOADS XML FILE

%-----------SETUP EXTERNAL LOADS-----------
el = ExternalLoads();
el.setName(trName);
el.setLowpassCutoffFrequencyForLoadKinematics(-1);
el.setDataFileName(sto_fname);

%-------------EXTERNAL FORCES--------------

%Ground reaction forces
grf1 = ExternalForce();
grf1.setName('Right_GRF');
grf1.setAppliedToBodyName(bodies{1,1});
grf1.setForceExpressedInBodyName(bodies{1,2});
grf1.setForceIdentifier(headings{2,1}(1:end-1));
grf1.setPointExpressedInBodyName(bodies{1,3});
grf1.setPointIdentifier(headings{5,1}(1:end-1));
grf1.setTorqueIdentifier(headings{8,1}(1:end-1));
el.cloneAndAppend(grf1);
grf2 = ExternalForce();
grf2.setName('Left_GRF');
grf2.setAppliedToBodyName(bodies{2,1});
grf2.setForceExpressedInBodyName(bodies{2,2});
grf2.setForceIdentifier(headings{11,1}(1:end-1));
grf2.setPointExpressedInBodyName(bodies{2,3});
grf2.setPointIdentifier(headings{14,1}(1:end-1));
grf2.setTorqueIdentifier(headings{17,1}(1:end-1));
el.cloneAndAppend(grf2);

%-------------SAVE FILE---------------
el.print(el_fname);
fprintf('\n      Printing External Loads File    \n')

return;

 